// メール詳細画面に表示するHTMLメールの本文に対して処理するためのJavaScript。

/** メール本文の上に配置するdivのid名。*/
var TOP_DIV_ID = "jp.co.yahoo.android.ymail.topDiv";

/** メール本文の下部にスペースを設けるために、bodyの上辺から下部まで配置するdivのid名。*/
var BOTTOM_DIV_ID = "jp.co.yahoo.android.ymail.bottomDiv";

/**
 * HTMLの上部にスペースができるようにするためのdivをHTMLに追加する。
 */
function createTopDiv() {
	var e = document.createElement('div');
	e.id = TOP_DIV_ID;
	document.body.insertBefore(e, document.body.childNodes[0]);
	return e;
}


/**
 * 【外部から呼び出すメソッド】
 * HTMLの上部にスペースができるように調整する。
 * (実際にはHTML最上部に指定の高さのdivを追加することで、スペースを調整している。)
 *
 * @param height Android上のpxを基準にした、メール本文の上部に追加したい余白の高さ
 * @param webViewScale このHTMLメールを表示しているWebViewの拡大率
 */
function changeTopDiv(height, webViewScale) {
	var e = document.getElementById(TOP_DIV_ID);
	if (!e) {
		e = createTopDiv();
	}
	e.style.height = height / webViewScale + "px";
}


/**
 * HTMLの底部にスペースができるようにするためのdivをHTMLに追加する。
 */
function createBottomDiv() {
	var e = document.createElement('div');
	e.id = BOTTOM_DIV_ID;
	e.style.position = "absolute";
	document.body.insertBefore(e, document.body.childNodes[0]);
	return e;
}

/**
 * HTMLの底部にスペースができるように調整する。
 * (実際にはHTML最上部から、"上部divの高さ+本文高さ+ここで指定する高さ のdivを
 *  position:absolute で指定することでbody全体の高さを調整している。)
 *
 * @param height Android上で表示したい(広告と本文の境界線Viewなどを含む)広告枠の高さ。
 */
function changeBottomMargin(height) {
	// htmlを読み込んだ最後に呼ばないとダメ。元からのjavascriptによって追加され、bodyの最後に追加されないおそれがある。
	var e = document.getElementById(BOTTOM_DIV_ID);
	if (!e) {
		e = createBottomDiv();
	}
	//position:absolute にしていると、0pxだと表示されないため幅1pxを設定。
	e.style.width = "1px";
	e.style.height = height + "px";
}

/**
 * 【外部から呼び出すメソッド】
 * HTMLの底部にスペースがつくように調整する。
 * (実際にはHTML最上部から、"上部divの高さ+本文高さ+ここで指定する高さ のdivを
 *  position:absolute で指定することでbody全体の高さを調整している。)
 *
 * @param adHeight Android上で表示したい(広告と本文の境界線Viewなどを含む)広告枠の高さ。
 * @param webViewScale このHTMLメールを表示しているWebViewの拡大率
 * @param csszoom cssでzoomを設定しているときは1.5など、その値を、していない時は1を設定する。
 * @param webViewHeight WebViewの高さ
 */
function setBottomMargin(adHeight, webViewScale, csszoom, webViewHeight) {
	changeBottomMargin(0);
	// 0にしておくことで↓で正確な本文部分の高さを取得できる。0にしないとヘッダー部を開閉するたびに伸びていく。
	var contentH = document.body.scrollHeight;
	var height = webViewHeight / webViewScale; //webView部分の高さ。これを考慮しないとHTMLメールがバグる。
	// 上部div+メール本文がwebViewよりも短い時に画面内に広告が入らないようにする。
	var mailH = height > contentH ? height : (contentH / csszoom);
	changeBottomMargin(mailH + (adHeight / webViewScale));
}
